AIOMatrix
=========

aiomatrix is a simple and fully asynchronous library for creating bots in `Matrix <https://matrix.org>`_ without hassle.


Resources
---------

- Community: `#aiomatrix-en <https://matrix.to/#/#aiomatrix:matrix.org>`_
- Russian community: `#aiomatrix-ru <https://matrix.to/#/#aiomatrix-ru:matrix.org>`_
- Source code: `Github <https://github.com/forden/aiomatrix>`_
- Issues: `Github bug tracker <https://github.com/forden/aiomatrix/issues>`_
